==> iframework-gwtpx-0.4.0-sources.jar: pro/redsoft/iframework/client/factory/ComponentPresenterFactory.java <==
/*
The MIT License (MIT)

Copyright (c) 2013 - 2014  REDSOFT.PRO

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package pro.redsoft.iframework.client.factory;

import pro.redsoft.iframework.client.presenter.ComponentPresenterWidget;
import pro.redsoft.iframework.client.view.ComponentView;

/**
 * Use this factory to create {@link ComponentPresenterWidget} objects.
 * 
 * @author Alex N. Oreshkevich
 * @param <V>
 * @param <P>
 */
public interface ComponentPresenterFactory<V extends ComponentView, P extends ComponentPresenterWidget<V>> {

  /**
   * Create a new {@link ComponentPresenterWidget}.
   * 
   * @return The newly created {@link ComponentPresenterWidget}.
   */
  P create();
}

==> iframework-gwtpx-0.4.1-sources.jar: pro/redsoft/iframework/client/factory/ComponentPresenterFactory.java <==
/*
The MIT License (MIT)

Copyright (c) 2013 - 2014  REDSOFT.PRO

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package pro.redsoft.iframework.client.factory;

import pro.redsoft.iframework.client.presenter.ComponentPresenterWidget;
import pro.redsoft.iframework.client.view.ComponentView;

/**
 * Use this factory to create {@link pro.redsoft.iframework.client.presenter.ComponentPresenterWidget} objects.
 *
 * @author Alex N. Oreshkevich
 * @param <V> ComponentView
 * @param <P> ComponentPresenterWidget
 * @version 0.4.1
 */
public interface ComponentPresenterFactory<V extends ComponentView, P extends ComponentPresenterWidget<V>> {

  /**
   * Create a new {@link pro.redsoft.iframework.client.presenter.ComponentPresenterWidget}.
   *
   * @return The newly created {@link pro.redsoft.iframework.client.presenter.ComponentPresenterWidget}.
   */
  P create();
}
